@@ -180,6 +180,11 @@ namespace points {
 // forward declaration
 template<typename T, Index Log2Dim> class PointDataLeafNode;
 
+// these aliases are disabled in one of the unit tests to ensure that
+// they are not used by the Point headers
+
+#ifndef OPENVDB_DISABLE_POINT_DATA_TREE_ALIAS
+
 /// @brief Point index tree configured to match the default VDB configurations.
 using PointDataTree = tree::Tree<tree::RootNode<tree::InternalNode<tree::InternalNode
     <PointDataLeafNode<PointDataIndex32, 3>, 4>, 5>>>;
@@ -188,6 +193,7 @@ using PointDataTree = tree::Tree<tree::RootNode<tree::InternalNode<tree::Interna
 /// @brief Point data grid.
 using PointDataGrid = Grid<PointDataTree>;
 
+#endif
 
 /// @brief  Deep copy the descriptor across all leaf nodes.
 ///
