@@ -171,7 +171,7 @@ fogToExt(const FogGridT &fogGrid,
 ///
 /// @param sdfGrid  An approximate signed distance field to the specified iso-surface.
 ///
-/// @param op       Functor with signature [](const Vec3R &xyz)->float that
+/// @param op       Functor with signature [](const Vec3R &xyz)->ExtValueT that
 ///                 defines the Dirichlet boundary condition, on the iso-surface,
 ///                 of the field to be extended.
 ///
@@ -183,7 +183,7 @@ fogToExt(const FogGridT &fogGrid,
 /// @param nIter    Number of iterations of the fast sweeping algorithm.
 ///                 Each iteration performs 2^3 = 8 individual sweeps.
 ///
-/// @note The only difference between this method and fogToEXT, defined above, is the
+/// @note The only difference between this method and fogToExt, defined above, is the
 ///       convention of the sign of the signed distance field.
 ///
 /// @details Topology of output grid is identical to that of the input grid, except
@@ -209,7 +209,7 @@ sdfToExt(const SdfGridT &sdfGrid,
 /// @param fogGrid  Scalar (floating-point) volume from which an
 ///                 iso-surface can be defined.
 ///
-/// @param op       Functor with signature [](const Vec3R &xyz)->float that
+/// @param op       Functor with signature [](const Vec3R &xyz)->ExtValueT that
 ///                 defines the Dirichlet boundary condition, on the iso-surface,
 ///                 of the field to be extended.
 ///
@@ -251,7 +251,7 @@ fogToSdfAndExt(const FogGridT &fogGrid,
 /// @param sdfGrid  Scalar (floating-point) volume from which an
 ///                 iso-surface can be defined.
 ///
-/// @param op       Functor with signature [](const Vec3R &xyz)->float that
+/// @param op       Functor with signature [](const Vec3R &xyz)->ExtValueT that
 ///                 defines the Dirichlet boundary condition, on the iso-surface,
 ///                 of the field to be extended.
 ///
@@ -285,7 +285,7 @@ sdfToSdfAndExt(const SdfGridT &sdfGrid,
                typename SdfGridT::ValueType isoValue = 0,
                int nIter = 1);
 
-/// @brief Dilates an existing signed distance filed by a specified number of voxels
+/// @brief Dilates an existing signed distance field by a specified number of voxels
 ///
 /// @return A shared pointer to the dilated signed distance field.
 ///
@@ -574,7 +574,7 @@ void FastSweeping<SdfGridT, ExtValueT>::computeSweepMaskLeafOrigins()
     LeafManagerT leafManager(mSweepMask);
 
     mSweepMaskLeafOrigins.resize(leafManager.leafCount());
-    tbb::atomic<size_t> sweepingVoxelCount = 0;
+    std::atomic<size_t> sweepingVoxelCount{0};
     auto kernel = [&](const LeafT& leaf, size_t leafIdx) {
         mSweepMaskLeafOrigins[leafIdx] = leaf.origin();
         sweepingVoxelCount += leaf.onVoxelCount();
@@ -939,6 +939,7 @@ struct FastSweeping<SdfGridT, ExtValueT>::InitSdf
     SdfValueT      mAboveSign;//sign of distance values above the iso-value
 };// FastSweeping::InitSdf
 
+
 /// Private class of FastSweeping to perform multi-threaded initialization
 template <typename SdfGridT, typename ExtValueT>
 template <typename OpT>
@@ -1010,6 +1011,20 @@ struct FastSweeping<SdfGridT, ExtValueT>::InitExt
 #endif
     }// FastSweeping::InitExt::run
 
+    // int implements an update if minD needs to be updated
+    template<typename ExtT = ExtValueT, typename SdfT = SdfValueT, typename std::enable_if<std::is_same<ExtT, int>::value, int>::type = 0>
+    void sumHelper(ExtT& sum2, ExtT ext, bool update, const SdfT& /* d2 */) const { if (update) sum2 = ext; }// int implementation
+
+    // non-int implements a weighted sum
+    template<typename ExtT = ExtValueT, typename SdfT = SdfValueT, typename std::enable_if<!std::is_same<ExtT, int>::value, int>::type = 0>
+    void sumHelper(ExtT& sum2, ExtT ext, bool /* update */, const SdfT&  d2) const { sum2 += static_cast<ExtValueT>(d2 * ext); }// non-int implementation
+
+    template<typename ExtT = ExtValueT, typename SdfT = SdfValueT, typename std::enable_if<std::is_same<ExtT, int>::value, int>::type = 0>
+    ExtT extValHelper(ExtT extSum, const SdfT& /* sdfSum */) const { return extSum; }// int implementation
+
+    template<typename ExtT = ExtValueT, typename SdfT = SdfValueT, typename std::enable_if<!std::is_same<ExtT, int>::value, int>::type = 0>
+    ExtT extValHelper(ExtT extSum, const SdfT& sdfSum) const {return ExtT((SdfT(1) / sdfSum) * extSum); }// non-int implementation
+
     void operator()(const LeafRange& r) const
     {
         ExtAccT acc(mExtGrid->tree());
@@ -1044,6 +1059,11 @@ struct FastSweeping<SdfGridT, ExtValueT>::InitExt
                         } else {//voxel is neighboring the iso-surface
                             SdfValueT sum1 = 0;
                             ExtValueT sum2 = zeroVal<ExtValueT>();
+                            // minD is used to update sum2 in the integer case,
+                            // where we choose the value of the extension grid corresponding to
+                            // the smallest value of d in the 6 direction neighboring the current
+                            // voxel.
+                            SdfValueT minD = std::numeric_limits<SdfValueT>::max();
                             for (int n=0, i=0; i<6;) {
                                 SdfValueT d = std::numeric_limits<SdfValueT>::max(), d2;
                                 if (mask.test(i++)) {
@@ -1063,10 +1083,12 @@ struct FastSweeping<SdfGridT, ExtValueT>::InitExt
                                     const Vec3R xyz(static_cast<SdfValueT>(ijk[0])+d*static_cast<SdfValueT>(FastSweeping::mOffset[n][0]),
                                                     static_cast<SdfValueT>(ijk[1])+d*static_cast<SdfValueT>(FastSweeping::mOffset[n][1]),
                                                     static_cast<SdfValueT>(ijk[2])+d*static_cast<SdfValueT>(FastSweeping::mOffset[n][2]));
-                                    sum2 += d2*ExtValueT(op(xform.indexToWorld(xyz)));
+                                    // If current d is less than minD, update minD
+                                    sumHelper(sum2, ExtValueT(op(xform.indexToWorld(xyz))), d < minD, d2);
+                                    if (d < minD) minD = d;
                                 }
                             }//look over six cases
-                            ext[voxelIter.pos()] = (SdfValueT(1) / sum1) * sum2;
+                            ext[voxelIter.pos()] = extValHelper(sum2, sum1);
                             sdf[voxelIter.pos()] = isAbove ? h / math::Sqrt(sum1) : -h / math::Sqrt(sum1);
                         }// voxel is neighboring the iso-surface
                     }// intersecting voxels
@@ -1296,6 +1318,28 @@ struct FastSweeping<SdfGridT, ExtValueT>::SweepingKernel
         inline operator bool() const { return v < SdfValueT(1000); }
     };// NN
 
+    /// @note   Extending an integer field is based on the nearest-neighbor interpolation
+    template<typename ExtT = ExtValueT, typename SdfT = SdfValueT, typename std::enable_if<std::is_same<ExtT, int>::value, int>::type = 0>
+    ExtT twoNghbr(const NN& d1, const NN& d2, const SdfT& /* w */, const ExtT& v1, const ExtT& v2) const { return d1.v < d2.v ? v1 : v2; }// int implementation
+
+    /// @note   Extending a non-integer field is based on a weighted interpolation
+    template<typename ExtT = ExtValueT, typename SdfT = SdfValueT, typename std::enable_if<!std::is_same<ExtT, int>::value, int>::type = 0>
+    ExtT twoNghbr(const NN& d1, const NN& d2, const SdfT& w, const ExtT& v1, const ExtT& v2) const { return ExtT(w*(d1.v*v1 + d2.v*v2)); }// non-int implementation
+
+    /// @note   Extending an integer field is based on the nearest-neighbor interpolation
+    template<typename ExtT = ExtValueT, typename SdfT = SdfValueT, typename std::enable_if<std::is_same<ExtT, int>::value, int>::type = 0>
+    ExtT threeNghbr(const NN& d1, const NN& d2, const NN& d3, const SdfT& /* w */, const ExtT& v1, const ExtT& v2, const ExtT& v3) const {
+        math::Vec3<SdfT> d(d1.v, d2.v, d3.v);
+        math::Vec3<ExtT> v(v1, v2, v3);
+        return v[static_cast<int>(math::MinIndex(d))];
+    }// int implementation
+
+    /// @note   Extending a non-integer field is based on a weighted interpolation
+    template<typename ExtT = ExtValueT, typename SdfT = SdfValueT, typename std::enable_if<!std::is_same<ExtT, int>::value, int>::type = 0>
+    ExtT threeNghbr(const NN& d1, const NN& d2, const NN& d3, const SdfT& w, const ExtT& v1, const ExtT& v2, const ExtT& v3) const {
+        return ExtT(w*(d1.v*v1 + d2.v*v2 + d3.v*v3));
+    }// non-int implementation
+
     void sweep()
     {
         typename ExtGridT::TreeType *tree2 = mParent->mExtGrid ? &mParent->mExtGrid->tree() : nullptr;
@@ -1386,8 +1430,10 @@ struct FastSweeping<SdfGridT, ExtValueT>::SweepingKernel
                                     d2.v -= update;
                                     // affine combination of two neighboring extension values
                                     const SdfValueT w = SdfValueT(1)/(d1.v+d2.v);
-                                    acc2->setValue(ijk, w*(d1.v*acc2->getValue(d1(ijk)) +
-                                                           d2.v*acc2->getValue(d2(ijk))));
+                                    const ExtValueT v1 = acc2->getValue(d1(ijk));
+                                    const ExtValueT v2 = acc2->getValue(d2(ijk));
+                                    const ExtValueT extVal = twoNghbr(d1, d2, w, v1, v2);
+                                    acc2->setValue(ijk, extVal);
                                 }//update ext?
                             }//update sdf?
                             continue;
@@ -1411,9 +1457,11 @@ struct FastSweeping<SdfGridT, ExtValueT>::SweepingKernel
                                 d3.v -= update;
                                 // affine combination of three neighboring extension values
                                 const SdfValueT w = SdfValueT(1)/(d1.v+d2.v+d3.v);
-                                acc2->setValue(ijk, w*(d1.v*acc2->getValue(d1(ijk)) +
-                                                       d2.v*acc2->getValue(d2(ijk)) +
-                                                       d3.v*acc2->getValue(d3(ijk))));
+                                const ExtValueT v1 = acc2->getValue(d1(ijk));
+                                const ExtValueT v2 = acc2->getValue(d2(ijk));
+                                const ExtValueT v3 = acc2->getValue(d3(ijk));
+                                const ExtValueT extVal = threeNghbr(d1, d2, d3, w, v1, v2, v3);
+                                acc2->setValue(ijk, extVal);
                             }//update ext?
                         }//update sdf?
                     }//test for non-negative determinant
@@ -1503,7 +1551,7 @@ sdfToExt(const SdfGridT &sdfGrid,
          typename SdfGridT::ValueType isoValue,
          int nIter)
 {
-  FastSweeping<SdfGridT> fs;
+  FastSweeping<SdfGridT, ExtValueT> fs;
   if (fs.initExt(sdfGrid, op, background, isoValue, /*isInputSdf*/true)) fs.sweep(nIter);
   return fs.extGrid();
 }
